@@ -12,6 +12,7 @@ warnings.simplefilter("ignore", RuntimeWarning)
 
 _INDICATOR_COLUMNS = ["okt_rotasjon", "spyling", "slag", "pumping"]
 _ID_COL = "id"
+_PRESSURE_COL = "trykk"
 _LABEL_COL = "comment_label"
 _CATEGORICAL_COLS = {"okt_rotasjon", "spyling", "slag", "pumping", "comment_label"}
 _FLOAT_COLS = {"trykk", "spyle", "sek10"}
@@ -87,6 +88,18 @@ def _correct_values(df: pd.DataFrame, mapping: dict) -> pd.DataFrame:
     return _df
 
 
+def _has_zero_or_negative_mean_pressure(group: pd.DataFrame) -> bool:
+    """Checks if the group's pressure mean is zero or negative
+
+    Args:
+        group (pd.DataFrame): Group of data, aka a borehole
+
+    Returns:
+        bool: True if the mean is zero or negative, False otherwise
+    """
+    return group[_PRESSURE_COL].mean() <= 0
+
+
 def _remove_huge_depth_gaps(df: pd.DataFrame, threshold: float) -> Tuple[pd.DataFrame, List[dict]]:
     _df = df.copy()
     # get difference between rows
@@ -130,6 +143,10 @@ def preprocess(df: pd.DataFrame) -> Tuple[pd.DataFrame, List[dict]]:
     for name, group in _df.groupby(_ID_COL):
         # Check if it has less than n_rows:
         if not _has_less_than_n_rows(group, _MIN_ROWS_TOT):
+            # Remove samples with negative or zero mean pressure
+            if _has_zero_or_negative_mean_pressure(group):
+                errors.append({"filename": name, "error": "Survey has zero or negative mean pressure"})
+                continue
             # Remove huge gaps
             group, error = _remove_huge_depth_gaps(group, _MAX_GAP)
             if error:
@@ -140,7 +157,6 @@ def preprocess(df: pd.DataFrame) -> Tuple[pd.DataFrame, List[dict]]:
             group[_LABEL_COL] = _fill_label_col(group, _LABEL_COL)
             # Clip values
             group = _correct_values(group, VALID_RANGES_TOT)
-
             # Standardize depth
             try:
                 groups.append(_standardize_depth(group))
@@ -148,7 +164,6 @@ def preprocess(df: pd.DataFrame) -> Tuple[pd.DataFrame, List[dict]]:
                 errors.append({"filename": name, "error": e})
         else:
             errors.append({"filename": name, "error": f"Skipped as it has less than {_MIN_ROWS_TOT} rows"})
-    
     out = pd.concat(groups)
     out.reset_index(inplace=True, drop=True)
     return out, errors
